#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var Program = require("commander");
var local_storage_1 = require("../local-storage");
var step_1 = require("../step");
/**
 Step CLI.
 */
Program
    .command('push')
    .description('Pushes a new step')
    .option('-m, --message [message]', 'A message describing the newly created step')
    .option('--allow-empty', 'Allow an empty step to be pushed')
    .action(function (options) {
    local_storage_1.localStorage.assertTortilla(true);
    step_1.Step.push(options.message, options);
});
Program
    .command('pop')
    .description('Pops the most recent step')
    .action(function () {
    local_storage_1.localStorage.assertTortilla(true);
    step_1.Step.pop();
});
Program
    .command('tag')
    .description('Mark this step as finished and move on to the next one')
    .option('-m, --message [message]', 'A message describing the newly created step')
    .action(function (options) {
    local_storage_1.localStorage.assertTortilla(true);
    step_1.Step.tag(options.message);
});
Program
    .command('edit [steps...]')
    .description('Edits the specified step/s')
    .option('--root [root]', 'Edit the root step (initial commit)')
    .option('--udiff [updateDiff]', 'Update step-diffs of manuals being rebased')
    .action(function (steps, options) {
    local_storage_1.localStorage.assertTortilla(true);
    if (options.root) {
        steps.unshift('root');
    }
    step_1.Step.edit(steps, options);
});
Program
    .command('sort [step]')
    .description('Adjust all step indexes from a given step index')
    .option('--root [root]', 'Adjust from root commit')
    .action(function (step, options) {
    local_storage_1.localStorage.assertTortilla(true);
    step = step || (options.root && 'root');
    step_1.Step.sort(step);
});
Program
    .command('reword [step]')
    .description("Rename the specified step's commit message")
    .option('-m, --message [message]', 'The new message of the reworded step')
    .option('--root', 'Reword the root step (initial commit)')
    .action(function (step, options) {
    local_storage_1.localStorage.assertTortilla(true);
    step = step || (options.root && 'root');
    step_1.Step.reword(step, options.message);
});
Program.parse(process.argv);
//# sourceMappingURL=tortilla-step.js.map